


04/16/93 E. Correia
WK#:581       MV#:3c
Breitkopf & Hărtel, Vol. 13 
Clarinet Quintet
Trio II
Violino II
1 0 
Group memberships: sound, score
sound: part 3 of 5
score: part 3 of 5
$  K:3   Q:2   T:3/4   C:4
rest   2        q
measure 1
rest   2        q
E4     2        q     u        p
E4     2        q     u
measure 2
rest   2        q
F#4    2        q     u
F#4    2        q     u
measure 3
rest   2        q
D4     2        q     u
D4     2        q     u
measure 4
rest   2        q
C#4    2        q     u
C#4    2        q     u
measure 5
rest   2        q
E4     2        q     u
E4     2        q     u
measure 6
D4     2        q     u
rest   2        q
G4     2        q n   u        (
measure 7
F#4    4        h     u
G4     2        q n   u
measure 8
F#4    4        h     u        )
rest   2        q
measure 9
rest   6
measure 10
rest   6
measure 11
A3     4        h     u        (
G#3    2        q #   u        )+
measure 12
A3     2        q     u
rest   2        q
mheavy4         :||:
/END
